aboutsummaryrefslogtreecommitdiff
path: root/src/include/taler_pq_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_pq_lib.h')
-rw-r--r--src/include/taler_pq_lib.h20
1 files changed, 18 insertions, 2 deletions
diff --git a/src/include/taler_pq_lib.h b/src/include/taler_pq_lib.h
index f45de61d9..860be0e4d 100644
--- a/src/include/taler_pq_lib.h
+++ b/src/include/taler_pq_lib.h
@@ -169,10 +169,11 @@ TALER_PQ_query_param_array_blinded_coin_hash (
/**
* Generate query parameter for an array of GNUNET_HashCode
*
* @param num number of elements in @e hash_codes
- * @param hashes array of GNUNET_HashCode
+ * @param hashes array of hashes
* @param db context for the db-connection
*/
struct GNUNET_PQ_QueryParam
@@ -183,6 +184,21 @@ TALER_PQ_query_param_array_hash_code (
/**
+ * Generate query parameter for an array of
+ * `struct TALER_DenominationHashP`
+ *
+ * @param num number of elements in @e hash_codes
+ * @param hashes array of GNUNET_HashCode
+ * @param db context for the db-connection
+ */
+struct GNUNET_PQ_QueryParam
+TALER_PQ_query_param_array_denom_hash (
+ size_t num,
+ const struct TALER_DenominationHashP *denom_hs,
+ struct GNUNET_PQ_Context *db);
+
+
+/**
* Generate query parameter for an array of amounts
*
* @param num of elements in @e amounts
@@ -169,10 +169,11 @@ TALER_PQ_query_param_array_blinded_coin_hash (
/**
- * Generate query parameter for an array of GNUNET_HashCode
+ * Generate query parameter for an array of
+ * `struct GNUNET_HashCode`.
*
* @param num number of elements in @e hash_codes